@@ -104,8 +104,12 @@ def preview_command(host, port, debug):
 )
 def build_command(url_root):
     res = urlparse(url_root)
-    app.config["PREFERRED_URL_SCHEME"] = res.scheme
-    app.config["SERVER_NAME"] = res.netloc
+    app.config["PREFERRED_URL_SCHEME"] = res.scheme or "http"
+    app.config["SERVER_NAME"] = res.netloc or "localhost"
+    if not res.netloc:
+        echo_yellow(
+            'WARNING: The url root does not contain a valid server name, "localhost" will be used.'
+        )
     app.config["APPLICATION_ROOT"] = res.path or "/"
     # mark as 'BUILDING' status, so that templates can react properly,
     app.config["BUILDING"] = True
@@ -155,9 +159,11 @@ def build(client):
 
     echo("Building custom pages...", nl=False)
     for dirname, _, files in os.walk(pages_folder):
+        if os.path.basename(dirname).startswith("."):
+            continue
         rel_dirname = os.path.relpath(dirname, pages_folder)
         os.makedirs(os.path.join(build_pages_folder, rel_dirname), exist_ok=True)
-        for file in files:
+        for file in filter(lambda f: not f.startswith("."), files):
             rel_path = os.path.join(rel_dirname, file)
             dst_rel_path = re.sub(r".md$", ".html", rel_path)
             dst_path = os.path.join(build_pages_folder, dst_rel_path)
